@@ -26,7 +26,7 @@ import socket
 import pickle
 import re
 
-__version__ = '0.5.0'
+__version__ = '0.5.3'
 
 import dbus
 from dbus.mainloop.glib import DBusGMainLoop
@@ -112,7 +112,7 @@ class Daemon:
             if pid > 0:
                 # exit from second parent
                 sys.exit(0) 
-        except OSError, e: 
+        except OSError, e:
             sys.stderr.write("fork #2 failed: %d (%s)\n" % (e.errno, e.strerror))
             sys.exit(1) 
     
@@ -194,7 +194,7 @@ class Daemon:
                 if os.path.exists(self.pidfile):
                     os.remove(self.pidfile)
             else:
-                print str(err)
+                logging.error(str(err))
                 sys.exit(1)
 
     def restart(self):
@@ -269,12 +269,16 @@ class KhweeteurDaemon(Daemon):
         self.bus.add_signal_receiver(self.update, path='/net/khertan/Khweeteur', dbus_interface='net.khertan.Khweeteur', signal_name='require_update')
         self.bus.add_signal_receiver(self.post_tweet, path='/net/khertan/Khweeteur', dbus_interface='net.khertan.Khweeteur', signal_name='post_tweet')
         self.threads = [] #Here to avoid gc 
+        self.me_users = {}
+        self.apis = {}
+        self.idtag = None
 
         #Cache Folder
         self.cache_path = os.path.join(os.path.expanduser("~"),\
                                  '.khweeteur', 'cache')
         if not os.path.exists(self.cache_path):
             os.makedirs(self.cache_path)
+
         #Post Folder
         self.post_path = os.path.join(os.path.expanduser("~"),\
                                  '.khweeteur', 'topost')
@@ -298,6 +302,13 @@ class KhweeteurDaemon(Daemon):
             action='',
             tweet_id='',
             ):
+
+        if not os.path.isdir(self.post_path):
+            try:
+                os.makedirs(self.post_path)
+            except IOError, e:
+                logging.debug('post_tweet:' + e)
+
         with open(os.path.join(self.post_path, str(time.time())), 'wb') as fhandle:
             post = {'shorten_url': shorten_url,
                     'serialize': serialize,
@@ -376,7 +387,7 @@ class KhweeteurDaemon(Daemon):
                                     api.PostUpdate(text,
                                             in_reply_to_status_id=int(post['tweet_id']),
                                             latitude=post['lattitude'], longitude=post['longitude'])
-                                logging.debug('Posted reply %s' % (text,))
+                                logging.debug('Posted reply %s : %s' % (text,post['tweet_id']))
                         elif post['action'] == 'retweet':
                             #Retweet
                                 if account['base_url'] == post['base_url'] \
@@ -485,6 +496,7 @@ class KhweeteurDaemon(Daemon):
         self.do_posts()
         self.retrieve()
         gobject.timeout_add_seconds(refresh_interval, self.update)
+
         return False
         
     def retrieve(self, options=None):
@@ -527,6 +539,7 @@ class KhweeteurDaemon(Daemon):
                         except StandardError, err:
                             logging.debug('Cannot remove : %s : %s' % (str(status.id), str(err)))
 
+
             nb_searches = settings.beginReadArray('searches')
             searches = []
             for index in range(nb_searches):
@@ -545,88 +558,88 @@ class KhweeteurDaemon(Daemon):
             logging.info('Found %s account' % (str(nb_accounts),))
             for index in range(nb_accounts):
                 settings.setArrayIndex(index)
-                #Worker
-                try:                               
-                    self.threads.append(KhweeteurRefreshWorker(\
-                                settings.value('base_url'),
-                                settings.value('consumer_key'),
-                                settings.value('consumer_secret'),
-                                settings.value('token_key'),
-                                settings.value('token_secret'),
-                                'HomeTimeline', self.dbus_handler))
-                except Exception, err:
-                    logging.error('Timeline : %s' % str(err))
+                access_token = settings.value('access_token')
+                if not access_token in self.apis:
+                    self.apis[access_token] = self.get_api(dict((key, settings.value(key)) for key in settings.allKeys()))
+                    self.me_users[access_token] = None
 
-                try:                                                   
-                    self.threads.append(KhweeteurRefreshWorker(\
-                                settings.value('base_url'),
-                                settings.value('consumer_key'),
-                                settings.value('consumer_secret'),
-                                settings.value('token_key'),
-                                settings.value('token_secret'),
-                                'Mentions', self.dbus_handler))
-                except Exception, err:
-                    logging.error('Mentions : %s' % str(err))
+                if not self.me_users[access_token]:
+                    try:
+                        self.me_users[access_token] = self.apis[access_token].VerifyCredentials().id
+                    except Exception, err:
+                        self.me_users[access_token] = None
+                        logging.error('VerifyCredential : %s' % str(err))
 
-                try:                               
-                    self.threads.append(KhweeteurRefreshWorker(\
-                                settings.value('base_url'),
-                                settings.value('consumer_key'),
-                                settings.value('consumer_secret'),
-                                settings.value('token_key'),
-                                settings.value('token_secret'),
-                                'DMs', self.dbus_handler))
-                except Exception, err:
-                    logging.error('DMs : %s' % str(err))
+                api = self.apis[access_token]
+                me_user_id = self.me_users[access_token]
 
-                #Start searches thread
-                for terms in searches:
+                #If have user:
+                if self.me_users[access_token]:
+
+                    #Worker
                     try:                               
                         self.threads.append(KhweeteurRefreshWorker(\
-                                    settings.value('base_url'),
-                                    settings.value('consumer_key'),
-                                    settings.value('consumer_secret'),
-                                    settings.value('token_key'),
-                                    settings.value('token_secret'),
-                                    'Search:'+terms, self.dbus_handler))
+                                    api,
+                                    'HomeTimeline', self.dbus_handler,
+                                    me_user_id))
                     except Exception, err:
-                        logging.error('Search %s: %s' % (terms,str(err)))
-
-                #Start retrieving the list
-                try:
+                        logging.error('Timeline : %s' % str(err))
+    
+                    try:                                                   
                         self.threads.append(KhweeteurRefreshWorker(\
-                                    settings.value('base_url'),
-                                    settings.value('consumer_key'),
-                                    settings.value('consumer_secret'),
-                                    settings.value('token_key'),
-                                    settings.value('token_secret'),
-                                    'RetrieveLists', self.dbus_handler))
-                except Exception, err:
-                    logging.error('Retrieving List error %s' % (str(err),))
-
-                #Start lists thread
-                for list_id,user in lists:
+                                    api,
+                                    'Mentions', self.dbus_handler,
+                                    me_user_id))
+                    except Exception, err:
+                        logging.error('Mentions : %s' % str(err))
+    
                     try:                               
                         self.threads.append(KhweeteurRefreshWorker(\
-                                    settings.value('base_url'),
-                                    settings.value('consumer_key'),
-                                    settings.value('consumer_secret'),
-                                    settings.value('token_key'),
-                                    settings.value('token_secret'),
-                                    'List:'+user+':'+list_id, self.dbus_handler))
+                                    api,
+                                    'DMs', self.dbus_handler,
+                                    me_user_id))
                     except Exception, err:
-                        logging.error('List %s: %s' % (list_id,str(err)))
-
-                try:                               
-                    for idx, thread in enumerate(self.threads):
-                        logging.debug('Try to run Thread : %s' % str(thread))
-                        try:
-                            self.threads[idx].start()
-                        except RuntimeError, err:
-                            logging.debug('Attempt to start a thread already running : %s' % (str(err),))
-                except:
-                    logging.error('Running Thread error')
-
+                        logging.error('DMs : %s' % str(err))
+    
+                    #Start searches thread
+                    for terms in searches:
+                        try:                               
+                            self.threads.append(KhweeteurRefreshWorker(\
+                                        api,
+                                        'Search:'+terms, self.dbus_handler,
+                                        me_user_id))
+                        except Exception, err:
+                            logging.error('Search %s: %s' % (terms,str(err)))
+    
+                    #Start retrieving the list
+                    try:
+                            self.threads.append(KhweeteurRefreshWorker(\
+                                        api,
+                                        'RetrieveLists', self.dbus_handler,
+                                        me_user_id))
+                    except Exception, err:
+                        logging.error('Retrieving List error %s' % (str(err),))
+    
+                    #Start lists thread
+                    for list_id,user in lists:
+                        try:                               
+                            self.threads.append(KhweeteurRefreshWorker(\
+                                        api,
+                                        'List:'+user+':'+list_id, self.dbus_handler,
+                                        me_user_id))
+                        except Exception, err:
+                            logging.error('List %s: %s' % (list_id,str(err)))
+    
+                    try:                               
+                        for idx, thread in enumerate(self.threads):
+                            logging.debug('Try to run Thread : %s' % str(thread))
+                            try:
+                                self.threads[idx].start()
+                            except RuntimeError, err:
+                                logging.debug('Attempt to start a thread already running : %s' % (str(err),))
+                    except:
+                        logging.error('Running Thread error')
+    
             
             settings.endArray()
 
@@ -655,9 +668,10 @@ if __name__ == "__main__":
             elif 'restart' == sys.argv[1]:
                     daemon.restart()
             else:
+                    logging.error('Unknown command')                    
                     print "Unknown command"
                     sys.exit(2)
             sys.exit(0)
     else:
-            print "usage: %s start|stop|restart" % sys.argv[0]
+            print "usage: %s start|stop|restart|startfromprefs" % sys.argv[0]
             sys.exit(2)
