@@ -322,6 +322,12 @@ class KhweeteurWin(QMainWindow):
         self.tb_list_button.setCheckable(True)
         self.tb_list_button.clicked.connect(self.show_list)
         self.list_tb_action.append(self.toolbar.addWidget(self.tb_list_button))
+
+        #Fullscreen
+        self.tb_fullscreen =  QAction(QIcon.fromTheme("general_fullsize"), 'Fullscreen', self)
+        self.tb_fullscreen.triggered.connect(self.do_tb_fullscreen)
+        self.toolbar.addAction(self.tb_fullscreen)
+        self.list_tb_action.append(self.tb_fullscreen)
         
         #Reply button (Action)
         self.tb_reply = QAction('Reply', self)
@@ -405,6 +411,13 @@ class KhweeteurWin(QMainWindow):
         
         self.geolocDoStart()
 
+    @pyqtSlot()
+    def do_tb_fullscreen(self):
+        if self.isFullScreen():
+            self.showMaximized()
+        else:
+            self.showFullScreen()        
+
     @pyqtSlot()
     def do_tb_copy(self):
         text = None
